.. _recipe_asr.deformationpotentials:

asr.deformationpotentials
=========================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.deformationpotentials`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.deformationpotentials.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.deformationpotentials

or as a python module

.. code-block:: console

   $ python -m asr.deformationpotentials

Detailed description
--------------------
Deformation potentials.

Steps
-----


asr.deformationpotentials
^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.deformationpotentials.main
   